import "./tasks/starfusion.wdl" as starfusion
import "./tasks/fastp.wdl" as fastp
import "./tasks/arriba.wdl" as arriba
import "./tasks/mixcr.wdl" as mixcr

workflow {{ project_name }} {
    String sample_id
    File fastq1
    File fastq2
    File starfusion_database_dir
    String starfusion_docker
    String starfusion_cluster
    String disk_size

    String fastp_docker
    String fastp_cluster
    String adapter_sequence
    String adapter_sequence_r2
    String umi_loc
    Int trim_front1
    Int trim_tail1
    Int max_len1
    Int trim_front2
    Int trim_tail2
    Int max_len2
    Int disable_adapter_trimming
    Int length_required
    Int umi_len
    Int UMI
    Int qualified_quality_phred
    Int length_required1
    Int disable_quality_filtering
    
    File STAR_INDEX_DIR
    File ASSEMBLY_FA
    File ANNOTATION_GTF
    String arriba_docker
    String arriba_cluster

    String mixcr_docker
    String mixcr_cluster


        call fastp.fastp as fastp {
                input:
                read1=fastq1,
                read2=fastq2,
                sample_id=sample_id,
                docker=fastp_docker,
                cluster=fastp_cluster,
                disk_size=disk_size,
                adapter_sequence=adapter_sequence,
                adapter_sequence_r2=adapter_sequence_r2,
                umi_loc=umi_loc,
                trim_front1=trim_front1,
                trim_tail1=trim_tail1,
                max_len1=max_len1,
                trim_front2=trim_front2,
                trim_tail2=trim_tail2,
                max_len2=max_len2,
                disable_adapter_trimming=disable_adapter_trimming,
                length_required=length_required,
                umi_len=umi_len,
                UMI=UMI,
                qualified_quality_phred=qualified_quality_phred,
                length_required1=length_required1,
                disable_quality_filtering=disable_quality_filtering
        }

        call starfusion.starfusion as starfusion {
                input:	
                sample_id=sample_id,
                fastq1=fastp.Trim_R1,
                fastq2=fastp.Trim_R2,
                database_dir=starfusion_database_dir,
                docker=starfusion_docker,
                cluster=starfusion_cluster,
                disk_size=disk_size

        }

        call arriba.arriba as arriba {
                input:
                sample_id=sample_id,
                fastq1=fastp.Trim_R1,
                fastq2=fastp.Trim_R2,
                STAR_INDEX_DIR=STAR_INDEX_DIR,
                ASSEMBLY_FA=ASSEMBLY_FA,
                ANNOTATION_GTF=ANNOTATION_GTF,
                disk_size=disk_size,
                docker=arriba_docker,
                cluster=arriba_cluster
        }

        call mixcr.mixcr as mixcr {
                input:
                sample_id=sample_id,
                fastq1=fastp.Trim_R1,
                fastq2=fastp.Trim_R2,
                docker=mixcr_docker,
                cluster=mixcr_cluster,
                disk_size=disk_size

        }


}	
